@@ -14,19 +14,24 @@ $o2->simple(5);
 AAA->a(7);
 AAA2->a(8);
 
+Class::Accessor::Inherited::XS::install_class_accessor("Jopa::foo");
+Jopa->foo(77);
+
 cmpthese(
     -2,
     {
         pkg_caix          => sub { AAA->a },
-        pkg_cag           => sub { AAA2->a },
-        pkg_gparent_caixs => sub { CCC->a },
-        pkg_gparent_cag   => sub { CCC2->a },
+#        pkg_cag           => sub { AAA2->a },
+#        pkg_gparent_caixs => sub { CCC->a },
+#        pkg_gparent_cag   => sub { CCC2->a },
         pkg_set_caix      => sub { AAA->a(42) },
-        pkg_set_cag       => sub { AAA2->a(42) },
+#        pkg_set_cag       => sub { AAA2->a(42) },
         obj_caix          => sub { $o->a },
-        obj_cag           => sub { $o2->a },
+#        obj_cag           => sub { $o2->a },
         obj_cxa           => sub { $o2->simple },
         obj_direct        => sub { $o2->{a} },
+        class_get         => sub { Jopa->foo },
+        class_set         => sub { Jopa->foo(42) },
     }
 );
 
